# Subtract numbers module

class calculate:

	def sub(a, b):
		"""Substract two numbers"""
		return a - b

	def add(a, b):
		"""Add two numbers"""
		return a + b

	def mult(a, b):
		"""Product of two numbers"""
		return a * b

	def div(a, b):
		"""Divide two numbers"""
		return a / b



from distutils.core import setup
setup(
  name = 'arithmetics-X',
  packages = ['arithmetics'],
  version = '0.1',
  license='MIT',
  description = 'Simple arithmetics and temperature conversions',
  author = 'SabeloX',
  author_email = 'sabelomtw@gmail.com',
  url = 'https://github.com/SabeloX/Arithmetics-X',
  download_url = 'https://github.com/SabeloX/Arithmetics-X/archive/0.1.tar.gz',
  keywords = ['SOME', 'MEANINGFULL', 'KEYWORDS'],   # Keywords that define your package best
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
